## Template for documentation

Thank you for taking the time to fill out this template!

### Title
Please provide a title or name for this issue.

### Issue with current documentation
Please make sure to leave a reference to the document/code you're referring to.

### Describe the feature you'd like to see
Please describe as clearly as possible what you think is missing from the current documentation.


### Checklist

- [ ] I have checked the list of [existing issues](https://gitlab.tudelft.nl/demoses/cronian/-/issues) and couldn't find an issue about this.


/label ~Documentation